@@ -3,6 +3,7 @@ import { setupRPC } from "imjoy-core/dist/imjoy-rpc";
 import {
   IFileBrowserFactory
 } from '@jupyterlab/filebrowser';
+import { ITranslator } from '@jupyterlab/translation';
 import {
   showErrorMessage,
 } from '@jupyterlab/apputils';
@@ -55,7 +56,7 @@ if not hasattr(ipykernel, 'connect'):
   }
 }
 
-async function parseURL(app, browser){
+async function parseURL(app, browser, trans){
   const queryString = window.location.search;
   const urlParams = new URLSearchParams(queryString);
   const urls = urlParams.getAll("load");
@@ -262,9 +263,10 @@ class ImjoyExtension {
 
 export default {
   id: 'imjoy-jupyterlab-extension',
-  requires: [IFileBrowserFactory],
+  requires: [IFileBrowserFactory, ITranslator],
   autoStart: true,
-  activate: async function (app, factory) {
+  activate: async function (app, factory, translator) {
+    const trans = translator.load('jupyterlab');
     const { defaultBrowser: browser } = factory;
     const jupyterBaseUrl =
     app.serviceManager.settings.serverSettings.baseUrl;
@@ -276,7 +278,7 @@ export default {
       'JupyterLab extension imjoy-jupyterlab-extension is activated!'
     );
 
-    await parseURL(app, browser);
+    await parseURL(app, browser, trans);
     
   }
 }
